Class: ForemanAnsibleDirector::Actions::ConsistencyCheck::Perform

Inherits:
Base::AnsibleDirectorAction show all
Includes:
Dynflow::Action::V2::WithSubPlans
Defined in:
app/lib/foreman_ansible_director/actions/consistency_check/perform.rb

Instance Method Summary collapse

Methods inherited from Base::AnsibleDirectorAction

#humanized_name, #queue, #task_output

Instance Method Details

#create_sub_plansObject



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'app/lib/foreman_ansible_director/actions/consistency_check/perform.rb', line 52

def create_sub_plans
  unreferenced_repository_hrefs = input[:unreferenced_repository_hrefs]
  unreferenced_distribution_hrefs = input[:unreferenced_distribution_hrefs]
  unreferenced_collection_remote_hrefs = input[:unreferenced_collection_remote_hrefs]
  unreferenced_role_remote_hrefs = input[:unreferenced_role_remote_hrefs]
  unreferenced_git_remote_hrefs = input[:unreferenced_git_remote_hrefs]

  trigger(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Destroy::Repositories,
    unreferenced_repository_hrefs: unreferenced_repository_hrefs
  )
  trigger(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Destroy::Distributions,
    unreferenced_distribution_hrefs: unreferenced_distribution_hrefs
  )
  trigger(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Destroy::CollectionRemotes,
    unreferenced_collection_remote_hrefs: unreferenced_collection_remote_hrefs
  )
  trigger(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Destroy::RoleRemotes,
    unreferenced_role_remote_hrefs: unreferenced_role_remote_hrefs
  )
  trigger(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Destroy::GitRemotes,
    unreferenced_git_remote_hrefs: unreferenced_git_remote_hrefs
  )
end

#plan(*_args) ⇒ Object

We'll have to see whether Pulp can handle this kind of request spam. If not, we have to use sequential execution and/or rate-limit requests.



17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'app/lib/foreman_ansible_director/actions/consistency_check/perform.rb', line 17

def plan(*_args)
  repo_check_action = plan_action(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Check::Repositories
  )
  distribution_check_action = plan_action(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Check::Distributions
  )
  collection_remote_check_action = plan_action(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Check::CollectionRemotes
  )
  role_remote_check_action = plan_action(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Check::RoleRemotes
  )
  git_remote_check_action = plan_action(
    ::ForemanAnsibleDirector::Actions::ConsistencyCheck::Check::GitRemotes
  )

  plan_self(
    unreferenced_repository_hrefs:
      repo_check_action.output[:unreferenced_repository_hrefs],
    unreferenced_distribution_hrefs:
      distribution_check_action.output[:unreferenced_distribution_hrefs],
    unreferenced_collection_remote_hrefs:
      collection_remote_check_action.output[:unreferenced_collection_remote_hrefs],
    unreferenced_role_remote_hrefs:
      role_remote_check_action.output[:unreferenced_role_remote_hrefs],
    unreferenced_git_remote_hrefs:
      git_remote_check_action.output[:unreferenced_git_remote_hrefs]
  )
end

#total_countObject



48
49
50
# File 'app/lib/foreman_ansible_director/actions/consistency_check/perform.rb', line 48

def total_count
  1
end