Class: ForemanAnsibleDirector::GitOps::BaseClient

Inherits:
Object
  • Object
show all
Defined in:
app/services/foreman_ansible_director/git_ops/base_client.rb

Overview

For now, this class is bloat, but if I ever need to configure Git in any way, I can use it.

Class Method Summary collapse

Class Method Details

.git_clientObject



9
10
11
# File 'app/services/foreman_ansible_director/git_ops/base_client.rb', line 9

def git_client
  Git
end